declare type DeploySentienlEventType = 'network' | 'dom' | 'log' | 'console' | 'hook' | 'browserLogEntry' | 'exception';
declare enum RunState {
    Failed = "failed",
    Passed = "passed",
    Pending = "pending",
    Running = "running",
    Skipped = "skipped"
}
declare type DSRun = {
    _id: string;
    s3PresignedUrls: {
        browser: string;
        plugin: string;
    };
};
declare type RunPayload = {
    batchId: string;
    ciProvider?: string;
    code: string;
    commitInfo?: CommitInfo;
    name: string;
    retryNumber: number;
    startedAt: Date;
    testName: string;
};
declare type PatchRunPayload = {
    completedAt: Date;
    took: number;
    state: string;
    errorTrace?: {
        message?: string;
        name: string;
        codeFrame?: {
            frame: string;
        };
        stack?: string;
        sourceMappedStack?: string;
    };
};
declare type CommitInfo = {
    authorEmail: string | null;
    authorName: string | null;
    branch: string | null;
    ciBuildId: string | null;
    defaultBranch: string | null;
    message: string | null;
    remoteBranch: string | null;
    remoteOrigin: string | null;
    sha: string | null;
    timestamp: number | null;
    metadata: unknown | null;
};
declare type APIClientBaseConfig = {
    apiKey: string;
    baseUrl: string;
    buildId: string;
    debuggerVersion: string;
    verbose?: boolean;
};
declare type LoggerMessage = {
    message: string | Error;
    location: string;
    meta?: {
        [key: string]: unknown;
    };
};
declare enum LoggerSeverity {
    Error = "error",
    Info = "info",
    Warning = "warning"
}

type types_DeploySentienlEventType = DeploySentienlEventType;
type types_RunState = RunState;
declare const types_RunState: typeof RunState;
type types_DSRun = DSRun;
type types_RunPayload = RunPayload;
type types_PatchRunPayload = PatchRunPayload;
type types_CommitInfo = CommitInfo;
type types_APIClientBaseConfig = APIClientBaseConfig;
type types_LoggerMessage = LoggerMessage;
type types_LoggerSeverity = LoggerSeverity;
declare const types_LoggerSeverity: typeof LoggerSeverity;
declare namespace types {
  export {
    types_DeploySentienlEventType as DeploySentienlEventType,
    types_RunState as RunState,
    types_DSRun as DSRun,
    types_RunPayload as RunPayload,
    types_PatchRunPayload as PatchRunPayload,
    types_CommitInfo as CommitInfo,
    types_APIClientBaseConfig as APIClientBaseConfig,
    types_LoggerMessage as LoggerMessage,
    types_LoggerSeverity as LoggerSeverity,
  };
}

declare class Logger {
    private readonly apiClient;
    private readonly verbose?;
    constructor(apiClient: APIClientBase, verbose?: boolean);
    info(loggerMessage: LoggerMessage): Promise<void>;
    warning(loggerMessage: LoggerMessage): Promise<void>;
    error(loggerMessage: LoggerMessage): Promise<void>;
}
declare class APIClientBase {
    private readonly apiKey;
    private readonly axiosInstance;
    private readonly buildId;
    private readonly debuggerVersion;
    private readonly verbose?;
    readonly logger: Logger;
    constructor(config: APIClientBaseConfig);
    sendMessage(error: Error, location: string, meta?: {
        [key: string]: unknown;
    }): Promise<void>;
}

declare class GitClient {
    private commitInfoCache;
    private readonly logger;
    constructor(logger: Logger);
    getCommitInfo(): Promise<CommitInfo>;
}

declare const _default: {
    GitClient: typeof GitClient;
    types: typeof types;
};

export { _default as default };
